@@ -1,6 +1,7 @@
 #include <stdlib.h>
 #define _GNU_SOURCE
 #include <getopt.h>
+#include <string.h>
 
 #include "args.h"
 #include "cfg.h"
@@ -35,6 +36,8 @@ void args_parse()
 	int c, optidx;
 	struct option opts[] = {
 		{"line", 1, NULL, 'l'},
+		{"detach", 0, NULL, 'd'},
+		{"config", 1, NULL, 'c'},
 //		{, , , },
 		{NULL, 0, NULL, 0}
 	};
@@ -47,7 +50,7 @@ void args_parse()
 	for (;;)
 	{
 		c = getopt_long(args_number, args_arguments,
-				"l:d", opts, &optidx);
+				"l:dc:", opts, &optidx);
 		
 		if ( c==-1 ) break;
 		
@@ -59,6 +62,13 @@ void args_parse()
 			case 'l':
 				if ( sscanf(optarg, "%u", &optidx) )
 					config->default_line = optidx;
+				break;
+			case 'd':
+				config->detach = TRUE;
+				break;
+			case 'c':
+				if ( !cfgfile ) cfgfile = strdup(optarg);
+				break;
 		}
 	}
 }
