@@ -7,6 +7,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <math.h>
 
 #include "callbacks.h"
@@ -320,7 +321,7 @@ on_mn_server_show_message_window_activate
 		gtk_widget_show(wnd_messages);
 	}
 	else
-		gtk_window_activate_focus(wnd_messages);
+		gtk_window_activate_focus(GTK_WINDOW(wnd_messages));
 }
 
 void
