@@ -4,6 +4,7 @@
 
 #include <gtk/gtk.h>
 
+#include <stdlib.h>
 #include <math.h>
 
 #include "callbacks_xlcm.h"
@@ -15,6 +16,7 @@
 #include "runtime.h"
 #include "netio.h"
 #include "proc_xlcm_lcp3.h"
+#include "askname.h"
 
 void
 on_wnd_acitivity_realize               (GtkWidget       *widget,
@@ -155,7 +157,7 @@ on_mn_popup_show_messages_activate     (GtkMenuItem     *menuitem,
 		gtk_widget_show(wnd_messages);
 	}
 	else
-		gtk_window_activate_focus(wnd_messages);
+		gtk_window_activate_focus(GTK_WINDOW(wnd_messages));
 }
 
 
