@@ -7,6 +7,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <getopt.h>
 
 #include "cfg.h"
 #include "user.h"
@@ -16,8 +17,12 @@
 #include "../config.h"
 #include "mysql_backend.h"
 
+#define DEFAULT_CFG_FILENAME "xlc.cfg"
+
 struct tConfig * config;
 
+char * cfgfile = NULL; /* config filename given as argument */
+
 int config_load_defaults()
 {
 	if ( !(config = g_malloc(sizeof(struct tConfig))) ) return(0);
@@ -48,6 +53,7 @@ int config_load_defaults()
 	config->mysql_user = NULL;
 	config->mysql_pass = NULL;
 	config->mysql_db = NULL;
+	config->detach = FALSE;
 	return(1);
 }
 
@@ -56,6 +62,7 @@ int config_load_defaults()
 void config_dump()
 {
 	g_print("--- CONFIG ---\n");
+	g_print("config file: %s\n", cfgfile);
 	g_print("server_hostname: %s\n", config->server_hostname);
 	g_print("server_port: %d\n", ntohs(config->server_port));
 	g_print("server_connect_on_startup: %d\n", config->server_connect_on_startup);
@@ -92,16 +99,26 @@ int config_load()
 #define READ_GBOOL(b)		if ( fscanf(fh, "%d", &dum) ) { if ( dum ) config->b = TRUE; else config->b = FALSE; }
 #define READ_INT(b)			fscanf(fh, "%d", &config->b);
 #define READ_STRING(s)	do { sdum[0] = '\0'; fscanf(fh, "%s", sdum); if (sdum[0] != '\0') config->s = g_strdup(sdum); } while (0)
-	FILE * fh;
+	FILE * fh = NULL;
 	int dum;
 	char sdum[200];
-	char * cfg_fname_sys = "/etc/xlc.cfg";
+	char * cfg_fname_sys = "/etc/"DEFAULT_CFG_FILENAME;
 	char * cfg_fname_user = user_get_homedir(getuid());
-	strcat(cfg_fname_user, "/.xlc.cfg");
+	strcat(cfg_fname_user, "/."DEFAULT_CFG_FILENAME);
 	*sdum = 0;
-	if ( !(fh = fopen(cfg_fname_user, "r")) )
-		if ( !(fh = fopen(cfg_fname_sys, "r")) )
-			return(0);
+	
+	if ( cfgfile ) fh = fopen(cfgfile, "r");
+	if ( !fh )
+	{
+		if ( !(fh = fopen(cfg_fname_user, "r")) )
+		{
+			if ( !(fh = fopen(cfg_fname_sys, "r")) )
+				return(0);
+			else cfgfile = strdup(cfg_fname_sys);
+		}
+		else cfgfile = strdup(cfg_fname_user);
+	}
+
 	fscanf(fh, "%s", sdum); config->server_hostname = g_strdup(sdum);
 	fscanf(fh, "%d", (int*)&(config->server_port));
 		config->server_port = htons(config->server_port);
@@ -148,9 +165,18 @@ int config_save()
 #define WRITE_INT(b)	fprintf(fh, "%d\n", config->b);
 #define WRITE_STRING(s)	{ if ( config->s ) fprintf(fh, "%s\n", config->s); else fprintf(fh, "\n"); }
 	FILE * fh;
-	char * cfg_fname_user = user_get_homedir(getuid());
-	strcat(cfg_fname_user, "/.xlc.cfg");
-	if ( !(fh = fopen(cfg_fname_user, "w")) ) return(0);
+/*	char * cfg_fname_user = user_get_homedir(getuid());
+	strcat(cfg_fname_user, "/.xlc.cfg");*/
+/*	if ( !(fh = fopen(cfg_fname_user, "w")) ) return(0);*/
+/*	if ( (!cfgfile) || (!(fh = fopen(cfgfile, "w"))) ) return 0;*/
+	if ( !cfgfile )
+	{
+		cfgfile = user_get_homedir(getuid());
+		if ( !cfgfile ) return 0;
+		strcat(cfgfile, "/."DEFAULT_CFG_FILENAME);
+	}
+	if ( !(fh = fopen(cfgfile, "w")) ) return 0;
+
 	fchmod(fileno(fh), S_IRUSR | S_IWUSR);
 	WRITE_STRING(server_hostname)
 	fprintf(fh, "%d\n", ntohs(config->server_port));
@@ -193,7 +219,9 @@ int config_save()
 int config_init()
 {
 	if ( !config_load_defaults() ) return(0);
+	args_parse();
 	config_load();
+	optind = 0; /* parse arguments again */
 	args_parse();
 	#if HAVE_LIBMYSQL
 		if ( config->mysql_enable )
