@@ -34,10 +34,13 @@ struct tConfig
 	char * mysql_pass;
 	char * mysql_db;
 	gboolean addrbook_ask;
+	gboolean detach;
 };
 
 extern struct tConfig *config;
 
+extern char * cfgfile; /* config filename given as argument */
+
 int config_save();
 int config_init();
 
