@@ -260,10 +260,10 @@ void proc_lcp3_process(gpointer data, gint sock, GdkInputCondition condition)
 				#endif
 			}
 			break;
-		default:
-			#ifdef DEBUG
+		#ifdef DEBUG
+			default:
 				g_print("Received invalid command: %d\n", cmd->cmd);
-			#endif
+		#endif
 	}
 	#ifdef DEBUG
 		g_print("\n");
@@ -450,7 +450,7 @@ void proc_status_tracker(int client, int linenum, int line, int channels, gboole
 				case 2:
 					gtk_check_menu_item_set_active(wdg_linemaster->mn_line_isdnchannels, TRUE);
 					break;
-				default:
+				default: ;
 			}
 		}
 		pline->channels = channels;
@@ -604,6 +604,7 @@ int proc_lcp3_cleanup()
 	gtk_clist_clear(wdg_linemaster->cl_lines);
 	runtime_save();
 	runtime_clear_lines();
+	proc_status_tracker(CLT_DISCON, 0, 0, 0, TRUE);
 	return 1;
 }
 
