@@ -22,7 +22,7 @@ gint proc_xlcm_lcp3_msg_callback_id;
 gboolean proc_xlcm_lcp3_msg_callback(gpointer ptr)
 {
 	if ( wdg_activity->lb_msg )
-		gtk_widget_hide(wdg_activity->lb_msg);
+		gtk_widget_hide(GTK_WIDGET(wdg_activity->lb_msg));
 //	gtk_window_set_default_size(wnd_activity, 142, 18);
 	proc_xlcm_lcp3_msg_callback_running = FALSE;
 	return FALSE;
@@ -232,7 +232,7 @@ void proc_xlcm_lcp3_process_command(gpointer data, gint sock, GdkInputCondition
 				msg->row[1] = g_strdup(info_isdn->caller);
 
 				gtk_label_set_text(wdg_activity->lb_msg, info_isdn->caller);
-				gtk_widget_show(wdg_activity->lb_msg);
+				gtk_widget_show(GTK_WIDGET(wdg_activity->lb_msg));
 				if ( proc_xlcm_lcp3_msg_callback_running )
 					gtk_timeout_remove(proc_xlcm_lcp3_msg_callback_id);
 				proc_xlcm_lcp3_msg_callback_id = gtk_timeout_add(ISDN_MSG_TIMEOUT*1000, proc_xlcm_lcp3_msg_callback, NULL);
