@@ -1,10 +1,11 @@
 #include <stdio.h>
+#include <stdlib.h>
 
 #include "args.h"
 #include "startup.h"
 #include "../config.h"
 
-char * startup_copy_right = "xlc[m] Copyright 2001 by S. Fuchs <sfuchs@gmx.net>\n\
+char * startup_copy_right = "xlc[m] Copyright 2001-2004 by S. Fuchs [http://linecontrol.srf.ch/]\n\
 Licensed under the GPL, see file LICENSE of the distribution package.\n";
 char * startup_version = "version: "VERSION"\n";
 
@@ -36,7 +37,7 @@ void startup_check(int argnum, char ** args)
 	{
 		printf("\nSupported options:\n");
 		printf("  --line=#       set default line ('-l #')\n");
-		printf("  --nodetach       don't fork into background ('-d')\n");
+		printf("  --detach       detach from terminal ('-d')\n");
 		printf("xlc[m] is part of the LineControl project.\n\
 For further explanation please refer to http://linecontrol.sourceforge.net/\n");
 		printf("\n");
