@@ -12,6 +12,7 @@ struct twdg_popup * wdg_popup;
 const char * wdg_names_activity[] = {
 	"prg_up",
 	"prg_down",
+	"lb_msg",
 	NULL
 };
 
@@ -34,6 +35,7 @@ void widgets_init()
 	wdg_messages->realized = FALSE;
 	wdg_popup = g_malloc(sizeof(struct twdg_popup));
 	wdg_popup->realized = FALSE;
+	widgets_cmn_init();
 }
 
 inline void widgets_load(GtkWidget *parent, const char * names[], gpointer * ptrs[])
